/*****************************************************************************
 *
 * FILE:	wkf.h
 * DESCRIPTION:	header file for WALL's Kanji Filter
 * DATE:	Sat, Jan 15 2000
 * AUTHOR:	Kouichi ABE (WALL) / 
 * E-MAIL:	kouichi@MysticWALL.com
 * URL:		http://www.MysticWALL.com/cover.html
 * COPYRIGHT:	(C) 1997-2002 졿Kouichi ABE (WALL), All rights reserved.
 * $Id: wkf.h,v 1.2.2.4.2.8 2002/10/02 15:50:14 kouichi Exp $
 *
 *****************************************************************************/
#ifndef	_wkf_h
#define	_wkf_h	1

/* Numeric release version identifier: MMNNFFRBB: major minor fix final beta */
#define	WKF_RELEASE	103020001

typedef enum {		/* kanji code type for API */
  KC_UNKNOWN = -1,	/* Unknown */
  KC_EUCorSJIS,		/* EUC-JP or Shift-JIS */
  KC_ASCII,		/* ASCII */
  KC_JIS,		/* JIS */
  KC_EUC,		/* EUC-JP */
  KC_SJIS,		/* Shift-JIS */
  KC_BROKEN,		/* broken file */
  KC_DATA		/* binary data */
} kcode_t;

typedef enum {		/* convert result type */
  CONV_ERR = -1,	/* any error was happened */
  CONV_NO,		/* no convert */
  CONV_OK		/* successful */
} conv_t;

typedef enum {	/* line end type */
  LE_LF,	/* usually used in UNIX */
  LE_CR,	/* usually used in Macintosh */
  LE_CRLF	/* usually used in MS-DOS/Windows */
} lineend_t;


#if	defined(__POWERPC__) || defined(__CFM68K__)
#undef	TRUE
#undef	FALSE
#endif	/* for Macintosh */

#ifndef _STRING_T
#define _STRING_T	1
typedef char *	String;
#endif	/* _STRING_T */

#ifndef	_BOOL_T
#define	_BOOL_T	1
typedef enum {	/* boolean type */
  FALSE,	/* false: 0 */
  TRUE,		/* true:  1 */
} bool_t;
#endif	/* _BOOL_T */


/* api.c */
extern void	wkfPrintGuessedKanjiCodeOfFile(FILE *, bool_t);

extern kcode_t	wkfGuessKanjiCodeOfFile(FILE *);
extern kcode_t	wkfGuessKanjiCodeOfString(char *);

extern conv_t	wkfConvertKanjiCodeOfFile(kcode_t, FILE *, kcode_t, FILE *);
extern conv_t	wkfConvertKanjiCodeOfString(kcode_t, char *, kcode_t, char *, unsigned int);

extern FILE *	wkfFileOpen(char *, kcode_t);
extern int	wkfFileClose(FILE *);


/* api2.c */
extern int	wkfEncodeBase64String(const String, String, size_t);
extern int	wkfDecodeBase64String(const String, String, size_t);
extern int	wkfEncodeBase64Bin(const String, size_t, String, size_t);
#define	wkfDecodeBase64Bin(a,b,c)	wkfDecodeBase64String((a),(b),(c))
extern void	wkfDecodeBase64File(FILE *, FILE *);

extern int	wkfEncodeQuotedPrintableString(const String, String, size_t);
extern int	wkfDecodeQuotedPrintableString(const String, String, size_t);
extern void	wkfDecodeQuotedPrintableFile(FILE *, FILE *);

extern conv_t	wkfDecodeMimeString(const String, String, size_t, kcode_t kout);
extern conv_t	wkfStringToHexString(const String, String, size_t);
extern conv_t	wkfMimeStringToHexString(const String, String, size_t);


/* conv.c */
extern void	wkfSetLineEndCode(lineend_t);
extern void	wkfConvertZenkaku2ASCII(bool_t);

#endif	/* _wkf_h */
